[−][src]Crate molt
Molt Client Library
This module is the primary API for Molt users.
Re-exports
pub use crate::interp::Interp; |
pub use crate::types::*; |
Modules
| interp | The Molt Interpreter |
| tokenizer | Tokenizer is a type used for parsing a |
| types | Public Type Declarations |
| value | The Value Type |
Macros
| molt_err | Returns an |
| molt_ok | This module contains macros for use by command authors.
Returns an |
Functions
| check_args | Checks to see whether a command's argument list is of a reasonable size. Returns an error if not. The arglist must have at least min entries, and can have up to max. If max is 0, there is no maximum. argv[0] is always the command name, and is included in the count; thus, min should always be >= 1. |
| list_to_string | Converts a list, represented as a vector of |